# -*- coding:utf-8 -*-
from client import start_client
from server import start_server


VERSION = '1.0.6'

AUTHOR = "cn"

AUTHOR_EMAIL = "308299269@qq.com"

URL = "https://www.github.com/ShichaoMa/custom_redis"

NAME = "custom-redis"

DESCRIPTION = "python实现简单redis，实现redis基本功能以及可插拔数据结构。 "